# PythonDice
This is a recreation of the language and capabilities of anydice.com using the python language

This project is still in very early development. (project started October 2024)

# Example Package

This is a simple example package. You can use
[GitHub-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

```
git status
git add
git commit
```